import java.awt.*;        
import processing.video.*;  // Camera capture
import hypermedia.video.*;  // OpenCV


OpenCV opencv;

// contrast/brightness values
int contrast_value    = 0;
int brightness_value  = 0;

Capture video;

void setup() 
{
    size(640,480);
    
    // init OpenCV    
    opencv = new OpenCV( this );
    // set image buffer size
    opencv.allocate(width,height);     
   
    // setup cascade mode
    opencv.cascade( dataPath("haarcascade/haarcascade_frontalface_alt.xml"));  

    // start camera capturing
//    video = new Capture(this, width,height,"/dev/video1");  // linux
    video = new Capture(this, width,height);
    video.start();

    // print usage
    println( "Drag mouse on X-axis inside this sketch window to change contrast" );
    println( "Drag mouse on Y-axis inside this sketch window to change brightness" );
}

public void stop() 
{
    opencv.stop();
    super.stop();
}

void draw() 
{
    if(!video.available()) 
     return;
     
    video.read();
    
    // copy the cam image to OpenCV
    opencv.copy(video);
   
    // convert to gray
    opencv.convert( GRAY );
    // change contrast
    opencv.contrast( contrast_value );
    // change brightness
    opencv.brightness( brightness_value );

    // detect face
    Rectangle[] faces = opencv.detect( 1.2, 2, OpenCV.HAAR_DO_CANNY_PRUNING, 40, 40 );
   // Rectangle[] faces = opencv.detect();

    // display the image
    image( opencv.image(), 0, 0 );

    // proceed detection    
    // draw face area(s)    
    noFill();
    stroke(255,0,0);
    for( int i=0; i<faces.length; i++ ) 
      rect( faces[i].x, faces[i].y, faces[i].width, faces[i].height ); 
}

void mouseDragged() 
{
    contrast_value   = (int) map( mouseX, 0, width, -128, 128 );
    brightness_value = (int) map( mouseY, 0, width, -128, 128 );
}


